@@ -103,7 +103,7 @@ class GenericSwitchDevice(object, metaclass=abc.ABCMeta):
         trunk_ports = self.ngs_config.get('ngs_trunk_ports')
         if not trunk_ports:
             return []
-        return trunk_ports.split(',')
+        return [port.strip() for port in trunk_ports.split(',')]
 
     def _get_port_default_vlan(self):
         """Return a default vlan of switch's interface if you specify."""
@@ -114,7 +114,7 @@ class GenericSwitchDevice(object, metaclass=abc.ABCMeta):
         physnets = self.ngs_config.get('ngs_physical_networks')
         if not physnets:
             return []
-        return physnets.split(',')
+        return [net.strip() for net in physnets.split(',')]
 
     def _disable_inactive_ports(self):
         """Return whether inactive ports should be disabled."""
@@ -151,3 +151,11 @@ class GenericSwitchDevice(object, metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def delete_port(self, port_id, segmentation_id):
         pass
+
+    def plug_bond_to_network(self, bond_id, segmentation_id):
+        # Fall back to interface method.
+        return self.plug_port_to_network(bond_id, segmentation_id)
+
+    def unplug_bond_from_network(self, bond_id, segmentation_id):
+        # Fall back to interface method.
+        return self.delete_port(bond_id, segmentation_id)
