@@ -177,6 +177,20 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
         m_sctd.assert_called_with([])
         m_check.assert_called_once_with('fake output', 'unplug port')
 
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.plug_port_to_network',
+                return_value='fake output')
+    def test_plug_bond_to_network_fallback(self, m_plug):
+        self.switch.plug_bond_to_network(2222, 22)
+        m_plug.assert_called_with(2222, 22)
+
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.delete_port',
+                return_value='fake output')
+    def test_unplug_bond_from_network_fallback(self, m_delete):
+        self.switch.unplug_bond_from_network(2222, 22)
+        m_delete.assert_called_with(2222, 22)
+
     def test__format_commands(self):
         self.switch._format_commands(
             netmiko_devices.NetmikoSwitch.ADD_NETWORK,
